# -*- coding: utf-8 -*-
from design.plone.contenttypes.interfaces.persona import IPersona
from design.plone.contenttypes.restapi.serializers.summary import (
    DefaultJSONSummarySerializer as BaseSerializer,
)
from design.plone.contenttypes.restapi.serializers.summary import (
    PersonaDefaultJSONSummarySerializer as BasePersonaSerializer,
)
from design.plone.ctgeneric.interfaces import IDesignPloneCtgenericLayer
from plone.restapi.interfaces import ISerializeToJsonSummary
from zope.component import adapter
from zope.interface import implementer
from zope.interface import Interface


@implementer(ISerializeToJsonSummary)
@adapter(Interface, IDesignPloneCtgenericLayer)
class DefaultJSONSummarySerializer(BaseSerializer):
    def __call__(self, **kwargs):
        res = super().__call__(**kwargs)
        if self.context.portal_type == "Persona":
            res["ruolo"] = getattr(self.context, "ruolo", "")
            res["incarichi"] = getattr(self.context, "ruolo", "")
        return res


@implementer(ISerializeToJsonSummary)
@adapter(IPersona, IDesignPloneCtgenericLayer)
class PersonaDefaultJSONSummarySerializer(BasePersonaSerializer):
    def __call__(self, **kwargs):
        res = super().__call__(**kwargs)
        res["ruolo"] = getattr(self.context, "ruolo", "")
        res["incarichi"] = getattr(self.context, "ruolo", "")
        return res



# -*- coding: utf-8 -*-
from design.plone.ctgeneric import _
from plone.restapi.controlpanels.interfaces import IControlpanel
from zope.interface import Interface
from zope.schema import SourceText

import json


class IDesignPloneV2SettingsControlpanel(IControlpanel):
    """ """


class IDesignPloneV2Settings(Interface):
    tipologie_notizia = SourceText(
        title=_("tipologie_notizia_label", default="Tipologie Notizia"),
        description=_(
            "tipologie_notizia_help",
            default="Inserisci i valori utilizzabili per le tipologie di una"
            " Notizia. Se il sito è multilingua, puoi inserire valori diversi"
            " a seconda delle lingue del sito.",
        ),
        required=True,
        default=json.dumps({"it": ["Avviso", "Comunicato (stampa)", "Notizia"]}),
    )
    tipologie_documento = SourceText(
        title=_("tipologie_documento_label", default="Tipologie Documento"),
        description=_(
            "tipologie_documento_help",
            default="Inserisci i valori utilizzabili per le tipologie di un "
            "Documento. Se il sito è multilingua, puoi inserire "
            "valori diversi a seconda delle lingue del sito.",
        ),
        required=True,
        default=json.dumps(
            {
                "it": [
                    "Accordi tra enti",
                    "Atti normativi",
                    "Dataset",
                    "Documenti (tecnici) di supporto",
                    "Documenti albo pretorio",
                    "Documenti attività politica",
                    "Documenti funzionamento interno",
                    "Istanze",
                    "Modulistica",
                ]
            }
        ),
    )
    tipologie_unita_organizzativa = SourceText(
        title=_(
            "tipologie_unita_organizzativa_label",
            default="Tipologie Unità Organizzativa",
        ),
        description=_(
            "tipologie_unita_organizzativa_help",
            default="Inserisci i valori utilizzabili per le tipologie di un' "
            "Unità Organizzativa. Se il sito è multilingua, puoi inserire "
            "valori diversi a seconda delle lingue del sito.",
        ),
        required=True,
        default=json.dumps({"it": ["Politica", "Amministrativa", "Altro"]}),
    )
    tipologie_persona = SourceText(
        title=_("tipologie_persona_label", default="Tipologie Persona"),
        description=_(
            "tipologie_persona_help",
            default="Inserisci i valori utilizzabili per le tipologie di "
            "una Persona. Se il sito è multilingua, puoi inserire "
            "valori diversi a seconda delle lingue del sito.",
        ),
        required=True,
        default=json.dumps({"it": ["Amministrativa", "Politica", "Altro tipo"]}),
    )

    ruoli_persona = SourceText(
        title=_("ruoli_persona_label", default="Ruoli Persona"),
        description=_(
            "ruoli_persona_help",
            default="Inserisci i valori utilizzabili per il ruolo di "
            "una Persona. Se il sito è multilingua, puoi inserire "
            "valori diversi a seconda delle lingue del sito.",
        ),
        required=True,
        default=json.dumps(
            {
                "it": [
                    "Assessore",
                    "Sindaco",
                    "Consigliere",
                    "Referente ufficio",
                    "Responsabile",
                    "Presidente",
                ]
            }
        ),
    )



# -*- coding: utf-8 -*-
from design.plone.contenttypes.testing import DesignPloneContenttypesLayer
from design.plone.contenttypes.testing import DesignPloneContenttypesRestApiLayer
from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import IntegrationTesting
from plone.testing import z2

import design.plone.ctgeneric
import plone.supermodel


class DesignPloneCtgenericLayer(DesignPloneContenttypesLayer):
    def setUpZope(self, app, configurationContext):
        # Load any other ZCML that is required for your tests.
        # The z3c.autoinclude feature is disabled in the Plone fixture base
        # layer.
        super().setUpZope(app, configurationContext)
        self.loadZCML(package=design.plone.ctgeneric)
        self.loadZCML(package=plone.supermodel)

    def setUpPloneSite(self, portal):
        super().setUpPloneSite(portal)
        applyProfile(portal, "design.plone.ctgeneric:default")


class DesignPloneCtgenericRestApiLayer(DesignPloneContenttypesRestApiLayer):
    def setUpZope(self, app, configurationContext):
        # Load any other ZCML that is required for your tests.
        # The z3c.autoinclude feature is disabled in the Plone fixture base
        # layer.
        super().setUpZope(app, configurationContext)
        self.loadZCML(package=design.plone.ctgeneric)

    def setUpPloneSite(self, portal):
        super().setUpPloneSite(portal)
        applyProfile(portal, "design.plone.contenttypes:default")
        applyProfile(portal, "design.plone.ctgeneric:default")


DESIGN_PLONE_CTGENERIC_FIXTURE = DesignPloneCtgenericLayer()
DESIGN_PLONE_CTGENERIC_API_FIXTURE = DesignPloneCtgenericRestApiLayer()

DESIGN_PLONE_CTGENERIC_INTEGRATION_TESTING = IntegrationTesting(
    bases=(DESIGN_PLONE_CTGENERIC_FIXTURE,),
    name="DesignPloneCtgenericLayer:IntegrationTesting",
)

DESIGN_PLONE_CTGENERIC_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(DESIGN_PLONE_CTGENERIC_FIXTURE,),
    name="DesignPloneCtgenericLayer:FunctionalTesting",
)

DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(DESIGN_PLONE_CTGENERIC_API_FIXTURE, z2.ZSERVER_FIXTURE),
    name="DesignPloneCtgenericRestApiLayer:Functional",
)



# -*- coding: utf-8 -*-
from design.plone.ctgeneric import _
from design.plone.ctgeneric.interfaces import IDesignPloneV2Settings
from plone.app.registry.browser.controlpanel import ControlPanelFormWrapper
from plone.app.registry.browser.controlpanel import RegistryEditForm


class DesignPloneV2ControlPanelForm(RegistryEditForm):
    schema = IDesignPloneV2Settings
    id = "design-plone-v2-control-panel"
    label = _("Impostazioni Design Plone V2")


class DesignPloneV2ControlPanelView(ControlPanelFormWrapper):
    """ """

    form = DesignPloneV2ControlPanelForm



# -*- coding: utf-8 -*-
from design.plone.contenttypes.tests.test_ct_documento import (
    TestDocumentoSchema as BaseSchemaTest,
)
from design.plone.ctgeneric.testing import DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING
from plone import api


class TestDocumentoSchema(BaseSchemaTest):
    layer = DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING

    def test_behaviors_enabled_for_documento(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual(
            portal_types["Documento"].behaviors,
            (
                "plone.namefromtitle",
                "plone.allowdiscussion",
                "plone.excludefromnavigation",
                "plone.shortname",
                "plone.dublincore",
                "plone.relateditems",
                "plone.locking",
                "plone.constraintypes",
                "plone.leadimage",
                "volto.preview_image",
                "design.plone.contenttypes.behavior.descrizione_estesa_documento",
                "design.plone.contenttypes.behavior.additional_help_infos",
                "plone.textindexer",
                "plone.translatable",
                "kitconcept.seo",
                "plone.versioning",
                "design.plone.contenttypes.behavior.documento_v2",
                "design.plone.contenttypes.behavior.argomenti_documento_v2",
            ),
        )

    def test_documento_fields_default_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Documento").json()
        self.assertEqual(
            resp["fieldsets"][0]["fields"],
            [
                "title",
                "description",
                "identificativo",
                "tipologia_documento",
                "image",
                "image_caption",
                "preview_image",
                "preview_caption",
                "tassonomia_argomenti",
            ],
        )

    def test_documento_fields_descrizione_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Documento").json()
        self.assertEqual(
            resp["fieldsets"][1]["fields"],
            [
                "ufficio_responsabile",
                "area_responsabile",
                "autori",
                "licenza_distribuzione",
                "descrizione_estesa",
            ],
        )

    def test_documento_required_fields(self):
        resp = self.api_session.get("@types/Documento").json()
        self.assertEqual(
            sorted(resp["required"]),
            sorted(["tipologia_documento", "title", "ufficio_responsabile"]),
        )



# -*- coding: utf-8 -*-
from design.plone.contenttypes.interfaces.persona import IPersona
from design.plone.ctgeneric import _
from plone.app.dexterity import textindexer
from plone.autoform import directives as form
from plone.autoform.interfaces import IFormFieldProvider
from plone.namedfile import field
from plone.supermodel import model
from zope import schema
from zope.component import adapter
from zope.interface import implementer
from zope.interface import provider


@provider(IFormFieldProvider)
class IPersonaV2(model.Schema):
    ruolo = schema.Choice(
        title=_("ruolo_label", default="Ruolo"),
        description=_(
            "ruolo_help",
            default="Seleziona il ruolo della persona tra quelli disponibili.",
        ),
        vocabulary="design.plone.contenttypes.RuoliPersona",
        required=True,
    )
    data_conclusione_incarico = schema.Date(
        title=_(
            "data_conclusione_incarico_label",
            default="Data conclusione incarico",
        ),
        description=_(
            "data_conclusione_incarico_help",
            default="Data di conclusione dell'incarico.",
        ),
        required=False,
    )

    tipologia_persona = schema.Choice(
        title=_("tipologia_persona_label", default="Tipologia persona"),
        description=_(
            "tipologia_persona_help",
            default="Seleziona la tipologia di persona: politica,"
            " amministrativa o di altro tipo.",
        ),
        vocabulary="design.plone.contenttypes.TipologiaPersona",
        required=True,
    )

    data_insediamento = schema.Date(
        title=_("data_insediamento_label", default="Data insediamento"),
        description=_(
            "data_insediamento_help",
            default="Solo per persona politica: specificare la data di"
            " insediamento.",
        ),
        required=False,
    )

    telefono = schema.List(
        title=_("telefono_persona_label", default="Numero di telefono"),
        description=_(
            "telefono_persona_help",
            default="Contatto telefonico della persona. E' possibile inserire "
            'più di un numero. Premendo "Invio" o "tab" si può passare al '
            "successivo da inserire.",
        ),
        value_type=schema.TextLine(),
        missing_value=[],
        default=[],
        required=False,
    )
    fax = schema.TextLine(
        title=_("fax_persona_label", default="Fax"),
        description=_("fax_persona_help", default="Indicare un numero di fax."),
        required=False,
    )
    email = schema.List(
        title=_("email_persona_label", default="Indirizzo email"),
        description=_(
            "email_persona_help",
            default="Contatto mail della persona. E' possibile inserire più"
            ' di un indirizzo. Premendo "Invio" o "tab" si può passare al '
            "successivo da inserire.",
        ),
        value_type=schema.TextLine(),
        missing_value=[],
        default=[],
        required=False,
    )

    atto_nomina = field.NamedFile(
        title=_("atto_nomina_label", default="Atto di nomina"),
        required=False,
        description=_(
            "atto_nomina_help",
            default="Inserire un file contenente l'atto di nomina della" " persona.",
        ),
    )

    # custom fieldsets
    model.fieldset(
        "ruolo",
        label=_("ruolo_label", default="Ruolo"),
        fields=[
            "ruolo",
            "data_conclusione_incarico",
            "tipologia_persona",
            "data_insediamento",
        ],
    )
    model.fieldset(
        "contatti",
        label=_("contatti_label", default="Contatti"),
        fields=["telefono", "fax", "email"],
    )
    model.fieldset(
        "documenti",
        label=_("documenti_label", default="Documenti"),
        fields=["atto_nomina"],
    )

    form.order_before(ruolo="organizzazione_riferimento")
    form.order_after(data_conclusione_incarico="organizzazione_riferimento")
    form.order_after(tipologia_persona="deleghe")
    form.order_before(data_insediamento="biografia")

    # # SearchableText fields
    textindexer.searchable("ruolo")
    textindexer.searchable("tipologia_persona")
    textindexer.searchable("telefono")
    textindexer.searchable("fax")
    textindexer.searchable("email")


@implementer(IPersonaV2)
@adapter(IPersona)
class PersonaV2(object):
    """"""

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from design.plone.contenttypes.restapi.services.types.get import TypesGet as BaseGet
from zope.interface import implementer
from zope.publisher.interfaces import IPublishTraverse


@implementer(IPublishTraverse)
class TypesGet(BaseGet):
    def customize_venue_schema(self, result):
        """
        Tolgo l'obbligatorietà forzata dal v3
        """
        schema = super().customize_venue_schema(result=result)

        fields = ["description", "image", "street", "city", "zip_code", "geolocation"]

        schema["required"] = [x for x in result.get("required", []) if x not in fields]
        return schema

    def customize_servizio_schema(self, result):
        """
        Tolgo l'obbligatorietà forzata dal v3
        """
        schema = super().customize_servizio_schema(result=result)

        fields = ["description"]

        schema["required"] = [x for x in result.get("required", []) if x not in fields]
        return schema

    def customize_evento_schema(self, result):
        """
        Tolgo l'obbligatorietà forzata dal v3
        """
        schema = super().customize_evento_schema(result=result)

        fields = ["description"]

        schema["required"] = [x for x in result.get("required", []) if x not in fields]
        return schema

    def customize_uo_schema(self, result):
        """
        Tolgo l'obbligatorietà forzata dal v3 e invalido la modifica
        """
        schema = result

        fields = ["description"]

        schema["required"] = [x for x in result.get("required", []) if x not in fields]
        return schema

    def customize_news_schema(self, result):
        """
        Tolgo l'obbligatorietà forzata dal v3
        """
        schema = super().customize_news_schema(result=result)

        fields = ["description"]

        schema["required"] = [x for x in result.get("required", []) if x not in fields]
        return schema

    def customize_documento_schema(self, result):
        """
        Tolgo l'obbligatorietà forzata dal v3
        """
        schema = super().customize_documento_schema(result=result)

        fields = ["description"]

        schema["required"] = [x for x in result.get("required", []) if x not in fields]
        return schema



# -*- coding: utf-8 -*-
from design.plone.ctgeneric.utils import get_settings_for_language
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary

import logging


logger = logging.getLogger(__name__)


class BaseVocabulary(object):
    def __call__(self, context):
        values = get_settings_for_language(field=self.field)
        if not values:
            return SimpleVocabulary([])

        terms = [SimpleTerm(value=x, token=x, title=x) for x in values]
        terms.insert(
            0,
            SimpleTerm(value="", token="", title="-- seleziona un valore --"),
        )

        return SimpleVocabulary(terms)


@implementer(IVocabularyFactory)
class RuoliPersona(BaseVocabulary):
    field = "ruoli_persona"


@implementer(IVocabularyFactory)
class TipologieNotizia(BaseVocabulary):
    """
    V2 Vocabulary
    """

    field = "tipologie_notizia"


@implementer(IVocabularyFactory)
class TipologieUnitaOrganizzativaVocabulary(BaseVocabulary):
    """
    V2 Vocabulary
    """

    field = "tipologie_unita_organizzativa"


@implementer(IVocabularyFactory)
class TipologieDocumento(BaseVocabulary):
    """
    V2 Vocabulary
    """

    field = "tipologie_documento"


@implementer(IVocabularyFactory)
class TipologiePersona(BaseVocabulary):
    """
    V2 Vocabulary
    """

    field = "tipologie_persona"


RuoliPersonaFactory = RuoliPersona()
TipologieNotiziaFactory = TipologieNotizia()
TipologieDocumentoFactory = TipologieDocumento()
TipologiePersonaFactory = TipologiePersona()
TipologieUnitaOrganizzativaVocabularyFactory = TipologieUnitaOrganizzativaVocabulary()



# -*- coding: utf-8 -*-

"""Setup tests for this package."""
from design.plone.ctgeneric.testing import DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING
from plone import api
from plone.app.testing import setRoles
from plone.app.testing import SITE_OWNER_NAME
from plone.app.testing import SITE_OWNER_PASSWORD
from plone.app.testing import TEST_USER_ID
from plone.restapi.testing import RelativeSession
from transaction import commit

import unittest


class TestBaseSerializer(unittest.TestCase):
    """"""

    layer = DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING

    def setUp(self):
        self.app = self.layer["app"]
        self.portal = self.layer["portal"]
        self.portal_url = self.portal.absolute_url()
        setRoles(self.portal, TEST_USER_ID, ["Manager"])

        self.api_session = RelativeSession(self.portal_url)
        self.api_session.headers.update({"Accept": "application/json"})
        self.api_session.auth = (SITE_OWNER_NAME, SITE_OWNER_PASSWORD)

    def tearDown(self):
        self.api_session.close()

    def test_design_italia_meta_type_news_with_tipologia(self):
        """
        News should return the news type (tipologia_notizia field)
        Other types shoule return their own portal_type.
        """
        news = api.content.create(
            container=self.portal,
            type="News Item",
            title="TestNews",
            tipologia_notizia="Foo",
        )
        commit()
        resp = self.api_session.get(news.absolute_url() + "?fullobjects")
        self.assertEqual(
            resp.json()["design_italia_meta_type"],
            news.tipologia_notizia,
        )

    def test_design_italia_meta_type_news_without_tipologia(self):
        """
        News should return the news type (tipologia_notizia field)
        Other types shoule return their own portal_type.
        """
        news = api.content.create(
            container=self.portal,
            type="News Item",
            title="TestNews",
        )
        commit()
        resp = self.api_session.get(news.absolute_url() + "?fullobjects")
        self.assertEqual(
            resp.json()["design_italia_meta_type"],
            "Notizie e comunicati stampa",
        )

    def test_design_italia_meta_type_with_type_different_from_news(self):
        """
        News should return the news type (tipologia_notizia field)
        Other types shoule return their own portal_type.
        """
        service = api.content.create(
            container=self.portal, type="Servizio", title="TestService"
        )
        commit()
        resp = self.api_session.get(service.absolute_url() + "?fullobjects")
        self.assertEqual(
            resp.json()["design_italia_meta_type"],
            "Servizio",
        )



# -*- coding: utf-8 -*-
from design.plone.ctgeneric import _
from plone.autoform import directives as form
from plone.autoform.interfaces import IFormFieldProvider
from plone.dexterity.interfaces import IDexterityContent
from plone.supermodel import model
from zope import schema
from zope.component import adapter
from zope.interface import implementer
from zope.interface import provider


@provider(IFormFieldProvider)
class IEventoV2(model.Schema):
    """
    Campi custom solo per la v2
    """

    telefono = schema.TextLine(
        title=_("telefono_event_help", default="Telefono"),
        description=_(
            "telefono_event_label",
            default="Indicare un riferimento telefonico per poter contattare"
            " gli organizzatori.",
        ),
        required=False,
    )
    fax = schema.TextLine(
        title=_("fax_event_help", default="Fax"),
        description=_("fax_event_label", default="Indicare un numero di fax."),
        required=False,
    )
    reperibilita = schema.TextLine(
        title=_("reperibilita", default="Reperibilità organizzatore"),
        required=False,
        description=_(
            "reperibilita_help",
            default="Indicare gli orari in cui l'organizzatore è"
            " telefonicamente reperibile.",
        ),
    )
    email = schema.TextLine(
        title=_("email_event_label", default="E-mail"),
        description=_(
            "email_event_help",
            default="Indicare un indirizzo mail per poter contattare"
            " gli organizzatori.",
        ),
        required=False,
    )

    web = schema.TextLine(
        title=_("web_event_label", default="Sito web"),
        description=_(
            "web_event_help",
            default="Indicare un indirizzo web di riferimento a " "questo evento.",
        ),
        required=False,
    )

    # custom tabs
    model.fieldset(
        "contatti",
        label=_("contatti_label", default="Contatti"),
        fields=[
            "telefono",
            "fax",
            "reperibilita",
            "email",
            "web",
        ],
    )

    form.order_after(telefono="organizzato_da_esterno")
    form.order_after(fax="telefono")
    form.order_after(reperibilita="fax")
    form.order_after(email="reperibilita")
    form.order_after(web="email")


@implementer(IEventoV2)
@adapter(IDexterityContent)
class EventoV2(object):
    """ """

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from design.plone.ctgeneric.testing import DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING
from plone import api
from plone.app.testing import setRoles
from plone.app.testing import SITE_OWNER_NAME
from plone.app.testing import SITE_OWNER_PASSWORD
from plone.app.testing import TEST_USER_ID
from plone.restapi.interfaces import ISerializeToJson
from plone.restapi.testing import RelativeSession
from transaction import commit
from zope.component import getMultiAdapter

import unittest


class SummarySerializerTest(unittest.TestCase):
    layer = DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING

    def setUp(self):
        self.app = self.layer["app"]
        self.portal = self.layer["portal"]
        self.request = self.layer["request"]
        self.portal_url = self.portal.absolute_url()

        self.api_session = RelativeSession(self.portal_url)
        self.api_session.headers.update({"Accept": "application/json"})
        self.api_session.auth = (SITE_OWNER_NAME, SITE_OWNER_PASSWORD)

        setRoles(self.portal, TEST_USER_ID, ["Manager"])

        self.document = api.content.create(
            container=self.portal, type="Document", title="Document"
        )
        commit()

    def tearDown(self):
        self.api_session.close()

    def test_summary_return_persona_role(self):
        api.content.create(
            container=self.portal, type="Persona", title="John Doe", ruolo="unknown"
        )
        api.content.create(container=self.portal, type="Persona", title="Mario Rossi")

        commit()

        brains = api.content.find(portal_type="Persona", id="mario-rossi")
        results = getMultiAdapter((brains, self.request), ISerializeToJson)(
            fullobjects=False
        )

        self.assertEqual(results["items"][0]["ruolo"], None)
        self.assertEqual(results["items"][0]["title"], "Mario Rossi")

        brains = api.content.find(portal_type="Persona", id="john-doe")
        results = getMultiAdapter((brains, self.request), ISerializeToJson)(
            fullobjects=False
        )

        self.assertEqual(results["items"][0]["ruolo"], "unknown")
        self.assertEqual(results["items"][0]["title"], "John Doe")

        # test also with restapi call
        response = self.api_session.get(
            "{}/@search?portal_type=Persona&id=mario-rossi".format(self.portal_url)
        )

        result = response.json()
        items = result.get("items", [])

        self.assertEqual(items[0]["title"], "Mario Rossi")
        self.assertEqual(items[0]["ruolo"], None)

        response = self.api_session.get(
            "{}/@search?portal_type=Persona&id=john-doe".format(self.portal_url)
        )

        result = response.json()
        items = result.get("items", [])

        self.assertEqual(items[0]["title"], "John Doe")
        self.assertEqual(items[0]["ruolo"], "unknown")



# -*- coding: utf-8 -*-
from design.plone.contenttypes.tests.test_ct_pagina_argomento import (
    TestPaginaArgomentoSchema as BaseSchemaTest,
)
from design.plone.ctgeneric.testing import DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING


class TestPaginaArgomentoSchema(BaseSchemaTest):
    layer = DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING



from design.plone.contenttypes.interfaces.persona import IPersona
from design.plone.contenttypes.restapi.serializers.persona import (
    PersonaSerializer as BaseSerializer,
)
from design.plone.ctgeneric.interfaces import IDesignPloneCtgenericLayer
from plone.restapi.interfaces import ISerializeToJson
from plone.restapi.serializer.converters import json_compatible
from zope.component import adapter
from zope.interface import implementer


@implementer(ISerializeToJson)
@adapter(IPersona, IDesignPloneCtgenericLayer)
class PersonaSerializer(BaseSerializer):
    def __call__(self, version=None, include_items=True):
        result = super().__call__(version=version, include_items=include_items)

        result["incarichi_persona"] = self.get_incarichi_v2()
        # temporary disabled
        result["contact_info"] = self.get_contacts_v2()
        return result

    def get_incarichi_v2(self):
        """
        Add infos about incarichi to emulate v3 schema
        """
        return [
            {
                "compensi": None,
                "compensi_file": [],
                "data_conclusione_incarico": json_compatible(
                    getattr(self.context, "data_conclusione_incarico", "")
                ),
                "data_inizio_incarico": "",
                "data_insediamento": json_compatible(
                    getattr(self.context, "data_insediamento", "")
                ),
                "tipologia_incarico": {
                    "title": getattr(self.context, "tipologia_persona", ""),
                    "token": getattr(self.context, "tipologia_persona", ""),
                },
                "title": getattr(self.context, "ruolo", ""),
                "type_title": "Incarico",
            }
        ]

    def get_contacts_v2(self):
        pdc = []
        for field in ["telefono", "fax", "email"]:
            value = getattr(self.context, field, "")
            if value:
                pdc.append({"pdc_type": field, "pdc_value": value})

        return [
            [
                {
                    "value_punto_contatto": pdc,
                }
            ]
        ]



# -*- coding: utf-8 -*-
from design.plone.contenttypes.interfaces.documento import IDocumento
from design.plone.ctgeneric.interfaces import IDesignPloneCtgenericLayer
from plone.restapi.deserializer.dxcontent import DeserializeFromJson
from plone.restapi.interfaces import IDeserializeFromJson
from zope.component import adapter
from zope.interface import implementer


@implementer(IDeserializeFromJson)
@adapter(IDocumento, IDesignPloneCtgenericLayer)
class DeserializeDocumentoFromJson(DeserializeFromJson):
    def __call__(self, validate_all=False, data=None, create=False):
        """
        Nel v3 ci sono validazioni sull'obbligatorietà
        """
        return super().__call__(validate_all=validate_all, data=data, create=create)



# -*- coding: utf-8 -*-
from design.plone.contenttypes.tests.test_ct_bando import (
    TestBandoSchema as BaseSchemaTest,
)
from design.plone.ctgeneric.testing import DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING


class TestBandoSchema(BaseSchemaTest):
    layer = DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING



# -*- coding: utf-8 -*-
from plone.registry.interfaces import IRegistry
from Products.CMFPlone.interfaces import INonInstallable
from Products.CMFPlone.interfaces import ISearchSchema
from zope.component import getUtility
from zope.interface import implementer


@implementer(INonInstallable)
class HiddenProfiles(object):
    def getNonInstallableProfiles(self):
        """Hide uninstall profile from site-creation and quickinstaller."""
        return [
            "design.plone.ctgeneric:uninstall",
        ]

    def getNonInstallableProducts(self):
        """Hide the upgrades package from site-creation and quickinstaller."""
        return ["design.plone.ctgeneric.upgrades"]


def post_install(context):
    """Post install script"""
    # Do something at the end of the installation of this package.
    disable_searchable_types()


def uninstall(context):
    """Uninstall script"""
    # Do something at the end of the uninstallation of this package.


def disable_searchable_types():
    # remove some types from search enabled ones
    registry = getUtility(IRegistry)
    settings = registry.forInterface(ISearchSchema, prefix="plone")
    remove_types = [
        "Dataset",
        "Documento Personale",
        "Messaggio",
        "Pratica",
        "RicevutaPagamento",
        "Incarico",
    ]
    types = [x for x in settings.types_not_searched if x not in remove_types]
    settings.types_not_searched = tuple(types)



# -*- coding: utf-8 -*-
from design.plone.contenttypes.tests.test_ct_event import (
    TestEventSchema as BaseSchemaTest,
)
from design.plone.ctgeneric.testing import DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING
from plone import api


class TestEventSchema(BaseSchemaTest):
    layer = DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING

    def test_behaviors_enabled_for_event(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual(
            portal_types["Event"].behaviors,
            (
                "plone.eventbasic",
                "plone.leadimage",
                "volto.preview_image",
                "plone.eventrecurrence",
                "design.plone.contenttypes.behavior.additional_help_infos",
                "design.plone.contenttypes.behavior.luoghi_correlati_evento",
                "design.plone.contenttypes.behavior.address_event",
                "design.plone.contenttypes.behavior.geolocation_event",
                "design.plone.contenttypes.behavior.strutture_correlate",
                "plone.dublincore",
                "plone.namefromtitle",
                "plone.allowdiscussion",
                "plone.excludefromnavigation",
                "plone.shortname",
                "plone.relateditems",
                "plone.versioning",
                "plone.locking",
                "plone.constraintypes",
                "plone.textindexer",
                "plone.translatable",
                "kitconcept.seo",
                "design.plone.contenttypes.behavior.argomenti",
                "design.plone.contenttypes.behavior.evento_v2",
            ),
        )

    def test_event_required_fields(self):
        """
        Override v3
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            sorted(resp["required"]),
            sorted(["title", "start", "end"]),
        )

    def test_event_fieldsets(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(len(resp["fieldsets"]), 13)
        self.assertEqual(
            [x.get("id") for x in resp["fieldsets"]],
            [
                "default",
                "cose",
                "luogo",
                "date_e_orari",
                "costi",
                "contatti",
                "informazioni",
                "correlati",
                "categorization",
                "dates",
                "settings",
                "ownership",
                "seo",
            ],
        )

    def test_event_fields_default_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            resp["fieldsets"][0]["fields"],
            [
                "title",
                "description",
                "start",
                "end",
                "whole_day",
                "open_end",
                "sync_uid",
                "image",
                "image_caption",
                "preview_image",
                "preview_caption",
                "recurrence",
                "tassonomia_argomenti",
                "sottotitolo",
            ]
            # should be like this, but in tests SchemaTweaks does not work
            # [
            #     "title",
            #     "description",
            #     "image",
            #     "image_caption",
            #     "preview_image",
            #     "preview_caption",
            #     "tassonomia_argomenti",
            #     "sottotitolo",
            # ],
        )

    def test_event_fields_contatti_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            resp["fieldsets"][5]["fields"],
            [
                "organizzato_da_interno",
                "organizzato_da_esterno",
                "supportato_da",
                "patrocinato_da",
                "telefono",
                "fax",
                "reperibilita",
                "email",
                "web",
            ],
        )

    def test_event_fields_informazioni_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            resp["fieldsets"][6]["fields"],
            ["ulteriori_informazioni", "strutture_politiche", "patrocinato_da"],
        )

    def test_event_fields_correlati_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            resp["fieldsets"][7]["fields"],
            ["correlato_in_evidenza"]
            # should be like this but SchemaTweaks does not work in tests
            # ["correlato_in_evidenza", "relatedItems"],
        )

    def test_event_fields_categorization_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            resp["fieldsets"][8]["fields"],
            ["subjects", "language", "relatedItems"]
            # should be like this with SchemaTweaks
            # ["subjects", "language"],
        )

    def test_event_fields_dates_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(resp["fieldsets"][9]["fields"], ["effective", "expires"])

    def test_event_fields_settings_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            resp["fieldsets"][10]["fields"],
            [
                "allow_discussion",
                "exclude_from_nav",
                "id",
                "versioning_enabled",
                "changeNote",
            ],
        )

    def test_event_fields_ownership_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            resp["fieldsets"][11]["fields"], ["creators", "contributors", "rights"]
        )

    def test_event_fields_seo_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Event").json()
        self.assertEqual(
            resp["fieldsets"][12]["fields"],
            [
                "seo_title",
                "seo_description",
                "seo_noindex",
                "seo_canonical_url",
                "opengraph_title",
                "opengraph_description",
                "opengraph_image",
            ],
        )



# -*- coding: utf-8 -*-
"""Init and utils."""
from design.plone.contenttypes.events import common
from design.plone.contenttypes.vocabularies import tags_vocabulary
from zope.i18nmessageid import MessageFactory


_ = MessageFactory("design.plone.ctgeneric")


subfolders_mapping = common.SUBFOLDERS_MAPPING

persona_folders = [
    x for x in subfolders_mapping["Persona"] if x["allowed_types"] != ("Incarico",)
]
persona_folders.extend(
    [
        {"id": "compensi", "title": "Compensi", "contains": ("File",)},
        {
            "id": "importi-di-viaggio-e-o-servizi",
            "title": "Importi di viaggio e/o servizi",
            "contains": ("File",),
        },
    ]
)
subfolders_mapping["Persona"] = persona_folders

common.SUBFOLDERS_MAPPING = subfolders_mapping


tags_vocabulary.TAGS_MAPPING = [
    ("anziano", _("Anziano")),
    ("fanciullo", _("Fanciullo")),
    ("giovane", _("Giovane")),
    ("famiglia", _("Famiglia")),
    ("studente", _("Studente")),
    ("associazione", _("Associazione")),
    ("istruzione", _("Istruzione")),
    ("abitazione", _("Abitazione")),
    ("animale-domestico", _("Animale domestico")),
    ("integrazione-sociale", _("Integrazione sociale")),
    ("protezione-sociale", _("Protezione sociale")),
    ("comunicazione", _("Comunicazione")),
    ("urbanistica-edilizia", _("Urbanistica ed edilizia")),
    ("formazione-professionale", _("Formazione professionale")),
    (
        "condizioni-organizzazione-lavoro",
        _("Condizioni e organizzazione del lavoro"),
    ),
    ("trasporto", _("Trasporto")),
    ("matrimonio", _("Matrimonio")),
    ("elezione", _("Elezione")),
    ("tempo-libero", _("Tempo libero")),
    ("cultura", _("Cultura")),
    ("immigrazione", _("Immigrazione")),
    ("inquinamento", _("Inquinamento")),
    ("area-parcheggio", _("Area di parcheggio")),
    ("traffico-urbano", _("Traffico urbano")),
    ("acqua", _("Acqua")),
    ("gestione-rifiuti", _("Gestione dei rifiuti")),
    ("salute", _("Salute")),
    ("sicurezza-pubblica", _("Sicurezza pubblica")),
    ("sicurezza-internazionale", _("Sicurezza internazionale")),
    ("spazio-verde", _("Spazio verde")),
    ("sport", _("Sport")),
    ("trasporto-stradale", _("Trasporto stradale")),
    ("turismo", _("Turismo")),
    ("energia", _("Energia")),
    (
        "informatica-trattamento-dati",
        _("Informatica e trattamento dei dati"),
    ),
]



# -*- coding: utf-8 -*-
from collective.volto.blocksfield.field import BlocksField
from design.plone.contenttypes.interfaces.servizio import IServizio
from design.plone.ctgeneric import _
from plone.autoform import directives as form
from plone.autoform.interfaces import IFormFieldProvider
from plone.supermodel import model
from zope.component import adapter
from zope.interface import implementer
from zope.interface import provider


@provider(IFormFieldProvider)
class IServizioV2(model.Schema):
    autenticazione = BlocksField(
        title=_("autenticazione", default="Autenticazione"),
        description=_(
            "autenticazione_help",
            default="Indicare, se previste, le modalità di autenticazione"
            " necessarie per poter accedere al servizio.",
        ),
        required=False,
    )

    model.fieldset("accedi_al_servizio", fields=["autenticazione"])

    form.order_after(autenticazione="canale_digitale")


@implementer(IServizioV2)
@adapter(IServizio)
class ServizioV2(object):
    """"""

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from collective.address.behaviors import IAddress
from design.plone.contenttypes.behaviors.address import IAddressLocal
from design.plone.contenttypes.behaviors.address import IAddressNomeSede
from design.plone.contenttypes.interfaces.unita_organizzativa import IUnitaOrganizzativa
from design.plone.ctgeneric import _
from plone.autoform.interfaces import IFormFieldProvider
from plone.supermodel import model
from zope.component import adapter
from zope.interface import implementer
from zope.interface import provider


@provider(IFormFieldProvider)
class IAddressUnitaOrganizzativa(IAddress, IAddressNomeSede, IAddressLocal):
    """ """

    model.fieldset(
        "contatti",
        label=_("contatti_label", default="Contatti"),
        fields=[
            "nome_sede",
            "street",
            "zip_code",
            "city",
            "quartiere",
            "circoscrizione",
            "country",
        ],
    )


@implementer(IAddressUnitaOrganizzativa)
@adapter(IUnitaOrganizzativa)
class AddressUnitaOrganizzativa(object):
    """ """

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from design.plone.ctgeneric import _
from plone.app.contenttypes.interfaces import INewsItem
from plone.autoform import directives as form
from plone.autoform.interfaces import IFormFieldProvider
from plone.supermodel import model
from zope import schema
from zope.component import adapter
from zope.interface import implementer
from zope.interface import provider


@provider(IFormFieldProvider)
class INewsV2(model.Schema):
    tipologia_notizia = schema.Choice(
        title=_("tipologia_notizia_label", default="Tipologia notizia"),
        description=_(
            "tipologia_notizia_help",
            default="Seleziona la tipologia della notizia.",
        ),
        required=True,
        vocabulary="design.plone.vocabularies.tipologie_notizia",
    )

    # custom fieldsets and order
    form.order_after(tipologia_notizia="descrizione_estesa")


@implementer(INewsV2)
@adapter(INewsItem)
class NewsV2(object):
    """ """

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from design.plone.contenttypes.tests.test_ct_luogo import (
    TestLuogoApi as BaseTestLuogoApi,
)
from design.plone.contenttypes.tests.test_ct_luogo import (
    TestLuogoSchema as BaseSchemaTest,
)
from design.plone.ctgeneric.testing import DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING
from plone import api
from transaction import commit
from uuid import uuid4


class TestLuogoSchema(BaseSchemaTest):
    layer = DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING

    def test_behaviors_enabled_for_luogo(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual(
            portal_types["Venue"].behaviors,
            (
                "plone.app.content.interfaces.INameFromTitle",
                "plone.app.dexterity.behaviors.id.IShortName",
                "plone.app.dexterity.behaviors.metadata.IBasic",
                "plone.app.dexterity.behaviors.metadata.ICategorization",
                "plone.excludefromnavigation",
                "plone.relateditems",
                "plone.leadimage",
                "volto.preview_image",
                "design.plone.contenttypes.behavior.argomenti",
                "design.plone.contenttypes.behavior.address_venue",
                "design.plone.contenttypes.behavior.geolocation_venue",
                "design.plone.contenttypes.behavior.additional_help_infos",
                "plone.textindexer",
                "plone.translatable",
                "kitconcept.seo",
                "plone.versioning",
                "design.plone.contenttypes.behavior.contatti_venue_v2",
                "design.plone.contenttypes.behavior.luogo_v2",
            ),
        )

    def test_luogo_required_fields(self):
        resp = self.api_session.get("@types/Venue").json()
        self.assertEqual(
            sorted(resp["required"]),
            sorted(
                [
                    "title",
                ]
            ),
        )

    def test_luogo_fields_default_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Venue").json()
        self.assertEqual(
            resp["fieldsets"][0]["fields"],
            [
                "title",
                "description",
                "image",
                "image_caption",
                "preview_image",
                "preview_caption",
                "tassonomia_argomenti",
                "nome_alternativo",
            ],
        )

    def test_luogo_fields_contatti_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Venue").json()
        self.assertEqual(
            resp["fieldsets"][5]["fields"],
            [
                "telefono",
                "fax",
                "email",
                "pec",
                "web",
                "struttura_responsabile_correlati",
                "struttura_responsabile",
                "riferimento_telefonico_struttura",
                "riferimento_fax_struttura",
                "riferimento_mail_struttura",
                "riferimento_pec_struttura",
            ],
        )

    def test_luogo_fields_categorization_fieldset(self):
        """
        Get the list from restapi
        """
        resp = self.api_session.get("@types/Venue").json()
        self.assertEqual(
            resp["fieldsets"][9]["fields"],
            # ["subjects", "language"] BBB dovrebbe essere così
            # ma nei test esce così perché non viene vista la patch di SchemaTweaks
            ["subjects", "language", "relatedItems"],
        )


class TestLuogoApi(BaseTestLuogoApi):
    layer = DESIGN_PLONE_CTGENERIC_API_FUNCTIONAL_TESTING

    def test_venue_geolocation_deserializer_right_structure(self):
        venue = api.content.create(
            container=self.portal, type="Venue", title="Example venue"
        )

        commit()
        self.assertEqual(venue.geolocation, None)

        text_uuid = str(uuid4())
        response = self.api_session.patch(
            venue.absolute_url(),
            json={
                "@type": "Venue",
                "title": "Foo",
                "geolocation": {"latitude": 11.0, "longitude": 10.0},
                "modalita_accesso": {
                    "blocks": {
                        text_uuid: {
                            "@type": "text",
                            "text": {"blocks": [{"text": "Test", "type": "paragraph"}]},
                        }
                    },
                    "blocks_layout": {"items": [text_uuid]},
                },
            },
        )
        self.assertEqual(response.status_code, 204)
